"""
Command line output of information on Mitiq and dependencies.
"""
__all__ = ['about']

import sys
import os
import platform
import numpy
import mitiq
import inspect

def about():
    """
    About box for Mitiq. Gives version numbers for mitiq, NumPy.
    """
    print("")
    print("Mitiq: A Python toolkit for implementing ")
    print("error mitigation on quantum computers.")
    print("========================================")
    print("Mitiq team – 2020 and later.")
    print("https://unitary.fund")
    print("")
    print("mitiq Version:      %s" % mitiq.__version__)
    print("Numpy Version:      %s" % numpy.__version__)
    print("Python Version:     %d.%d.%d" % sys.version_info[0:3])
    print("Platform Info:      %s (%s)" % (platform.system(),
                                           platform.machine()))
    mitiq_install_path = os.path.dirname(inspect.getsourcefile(mitiq))
    print("Installation path:  %s" % mitiq_install_path)

if __name__ == "__main__":
    about()


# matrices.py
import numpy as np

npI = np.array([[1, 0], [0, 1]])
"""Defines the identity matrix in SU(2) algebra as a (2,2) `np.array`."""

npX = np.array([[0, 1], [1, 0]])
"""Defines the sigma_x Pauli matrix in SU(2) algebra as a (2,2) `np.array`."""

npY = np.array([[0, -1j], [1j, 0]])
"""Defines the sigma_y Pauli matrix in SU(2) algebra as a (2,2) `np.array`."""

npZ = np.array([[1, 0], [0, -1]])
"""Defines the sigma_z Pauli matrix in SU(2) algebra as a (2,2) `np.array`."""



# Licensed under ...
"""
This is the top level module from which functions and classes of
Mitiq can be directly imported.
"""
import os
from typing import Union

_directory_of_this_file = os.path.dirname(os.path.abspath(__file__))


with open(str(_directory_of_this_file) + "/../VERSION.txt", "r") as f:
    __version__ = f.read().strip()

def version():
    """Returns the Mitiq version number."""
    return __version__



from setuptools import setup

with open("VERSION.txt", "r") as f:
    __version__ = f.read().strip()

with open('development_requirements.txt') as f:
    dev_requirements = f.read().splitlines()

NAME = "mitiq"
AUTHOR = "Ryan LaRose, Andrea Mari, Nathan Shammah, Will Zeng"
URL = "https://github.com/unitaryfund"
LICENSE = "GPL v3.0"
setup(
    name=NAME,
    version=__version__,
    packages = ['mitiq'],
    install_requires=['numpy>=1.18.1'],
    dev_requirements={'pytest>=5.4.1'},
    author=AUTHOR,
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url = URL,
   classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: MacOS",
        "Operating System :: Unix",
        "Operating System :: Microsoft :: Windows"
        ],
    license = LICENSE
)
